Surface

Struct Surface 

pub struct Surface { /* private fields */ }

Implementations

Source

impl Surface

pub fn size(&self) -> (usize, usize)

Returns size of the surface as (width, height) tuple

pub fn put_pixel(&mut self, x: usize, y: usize, color: Color)

Puts a pixel on the surface

This function is supposed to be called from the draw callback as passed to the begin_draw function.

Coordinate system: Origin (0, 0) is at top left, with (X, Y) axis going left-to-right, top-to-bottom.

Arguments
  • x - X-coordinate
  • y - Y-coordinate
  • color - Color of the pixel
pub fn begin_draw<F>(&mut self, draw_frame: F)
where F: FnMut(&mut Self),

Begins drawing on the surface.

Arguments
  • draw_frame - This function is called to draw a single frame at a time. The callback is called at a fixed rate of 60 fps.
Examples
use fbdraw::{Color, Surface};

let mut surface = Surface::new(1920, 1200);

surface.begin_draw(my_draw_frame);

// Draw a frame on the surface. This function is
// called at a fixed rate of 60 fps.
fn my_draw_frame(surface: &mut Surface) {
    let (width, height) = surface.size();
    surface.put_pixel(width / 2, height / 2, Color::rgb(255, 0, 0));
}
pub fn new(width: usize, height: usize) -> Surface

Creates a new surface of the given size

Arguments
  • width - Width of the surface in pixels
  • height - Height of the surface in pixels